@@ -1,10 +1,8 @@
-import sys
-from os.path import dirname, abspath
-sys.path.insert(0, dirname(dirname(abspath(__file__))))
-from log import Log
+from py3db.log.Log import Log, singleton
 from pymysql import connect
 
 
+@singleton
 class MySql:
     def __init__(self, ip, user_name, password, database):
         self.ip = ip
@@ -12,7 +10,7 @@ class MySql:
         self.password = password
         self.database = database
         self.db = None
-        self.log = Log.Log("mysql.log")
+        self.log = Log("mysql.log")
         self.create_connect()
 
     def __str__(self) -> str:
@@ -43,7 +41,6 @@ class MySql:
             self.log.call_error()
             self.log.error(str(e))
 
-
     def close_connect(self):
         try:
             self.db.close()
@@ -62,10 +59,10 @@ class MySql:
             self.log.error("{0} {1} {2}".format(
                 e, variable_name, variable
             ))
-    
+
     def __del__(self):
         if not self.db and not self:
-                self.db.close_connect()
+            self.db.close_connect()
 
 
 if __name__ == "__main__":
